<?php

/**
 * Listing Types - Default
 */


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if( !class_exists( 'Dt_Woo_Listing_Type_Default' ) ) {

    class Dt_Woo_Listing_Type_Default {

        private static $_instance = null;

        private $type_slug;

        private $type_name;

        public static function instance() {

            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;

        }

        function __construct() {

            /* Initialize Type */
                $this->type_slug = 'default';
                $this->type_name = esc_html__('Default', 'escoot');

            /* Backend Render */
                $this->render_backend();

        }

        /*
        Module Paths
        */

            function module_dir_path() {

                if( escoot_is_file_in_theme( __FILE__ ) ) {
                    return ESCOOT_MODULE_DIR . '/woocommerce/listings/types/';
                } else {
                    return trailingslashit( plugin_dir_path( __FILE__ ) );
                }

            }

            function module_dir_url() {

                if( escoot_is_file_in_theme( __FILE__ ) ) {
                    return ESCOOT_MODULE_URI . '/woocommerce/listings/types/';
                } else {
                    return trailingslashit( plugin_dir_url( __FILE__ ) );
                }

            }

        /*
        Backend Render
        */
            function render_backend() {

                /* Custom Product Templates - Options */
                    add_filter( 'dt_theme_woo_default_product_templates', array( $this, 'woo_default_product_templates'), 10, 1 );

            }

        /*
        Custom Product Templates - Options
        */
            function woo_default_product_templates( $templates ) {

                $type_options = array_merge (
                    array( 'product-template-id' => $this->type_name ),
                    $this->set_type_options()
                );

                $default_template = array (
                    'id'              => 'dt-woo-product-style-template-'.$this->type_slug,
                    'type'            => 'group',
                    'dt_default_type' => true,
                    'title'           => sprintf( esc_html__( 'Product Templates - %1$s', 'escoot' ), $this->type_name ),
                    'button_title'    => esc_html__('Add New', 'escoot'),
                    'accordion_title' => esc_html__('Add New Template', 'escoot'),
                    'fields'          => dt_woo_listing_fw_template_settings()->woo_get_options_params( $type_options, 'default' ),
                    'default'         => array ( 0 => $type_options )
                );

                array_push( $templates, $default_template );

                return $templates;

            }

        /*
        Set Type Options
        */
            function set_type_options() {

                $type_options = array ();

                $type_options['product-template-id']                   = 'Default Style';
                $type_options['product-style']                         = 'product-style-default';
                $type_options['product-hover-style']                   = '';
                $type_options['product-hover-image-effect']            = '';
                $type_options['product-hover-secondary-image-effect']  = 'product-hover-secimage-fade';
                $type_options['product-overlay-effect']				   = 'product-overlay-gradientbottomtotop';
                $type_options['product-overlay-dark-bgcolor']		   = 'product-overlay-dark-bgcolor';
                $type_options['product-icongroup-hover-effect']        = 'product-icongroup-hover-bounce';
                $type_options['product-content-hover-effect']		   = 'product-content-hover-slidebottom';
                $type_options['product-display-type']                  = 'grid';
                $type_options['product-display-type-list-option']      = 'left-thumb';
                $type_options['product-space']                         = 'product-with-space';
                $type_options['product-border-type']				   = 'product-border-type-default';
                $type_options['product-border-position']			   = 'product-border-position-default';
                $type_options['product-shadow-type']				   = 'product-shadow-type-thumb';
                $type_options['product-custom-class']				   = 'dt-custom-product-layout-i';
                $type_options['product-show-label']                    = 'false';
                $type_options['product-label-design']                  = 'product-label-boxed';
                $type_options['product-show-custom-type']			   = 'false';
                $type_options['product-thumb-secondary-image-onhover'] = 1;
                $type_options['product-thumb-content']                 = array (
                    'enabled'      => array (
                        'category'       => esc_html__('Category', 'escoot'),
                        'title'          => esc_html__('Title', 'escoot'),
                        'price'          => esc_html__('Price', 'escoot'),
                        'element_group'  => esc_html__('Element Group', 'escoot'),
                        'icons_group'    => esc_html__('Icons Group', 'escoot'),
                    ),
                    'disabled'     => array (
                        'excerpt'        => esc_html__('Excerpt', 'escoot'),
                        'rating'         => esc_html__('Rating', 'escoot'),
                        'button_element' => esc_html__('Button Element', 'escoot'),
                        'countdown'      => esc_html__('Count Down', 'escoot'),
                        'separator'      => esc_html__('Separator', 'escoot'),
                        'swatches'       => esc_html__('Swatches', 'escoot')
                    )
                );
                $type_options['product-thumb-alignment']           = 'product-thumb-alignment-middle';
                $type_options['product-thumb-iconsgroup-icons']    = array ( 'cart', 'wishlist', 'quickview' );
                $type_options['product-thumb-iconsgroup-position'] = 'product-thumb-iconsgroup-position-vertical vertical-position-top-right';
                $type_options['product-thumb-iconsgroup-style']    = 'product-thumb-iconsgroup-style-bgfill-rounded';
                $type_options['product-thumb-buttonelement-style'] = 'product-thumb-buttonelement-style-brdrfill-rounded';
                $type_options['product-thumb-buttonelement-stretch'] = 'product-thumb-buttonelement-stretch';
                $type_options['product-thumb-element-group']       = array (
                    'enabled'      => array (
                        'cart'         => esc_html__('Cart', 'escoot'),
                    ),
                    'disabled'     => array (
						'quickview'      => esc_html__('Quick View', 'escoot'),
						'price'          => esc_html__('Price', 'escoot'),
						'title'          => esc_html__('Title', 'escoot'),
						'wishlist'       => esc_html__('Wishlist', 'escoot'),
						'compare'        => esc_html__('Compare', 'escoot'),
						'category'       => esc_html__('Category', 'escoot'),
						'button_element' => esc_html__('Button Element', 'escoot'),
						'icons_group'    => esc_html__('Icons Group', 'escoot'),
						'excerpt'        => esc_html__('Excerpt', 'escoot'),                        
						'rating'         => esc_html__('Rating', 'escoot'),
						'separator'      => esc_html__('Separator', 'escoot'),
						'swatches'       => esc_html__('Swatches', 'escoot')
                    )
                );
                $type_options['product-content-enable']            = '1';
                $type_options['product-content-content']           = array (
                    'enabled'      => array (                        
                        'title'          => esc_html__('Title', 'escoot'),
                        'excerpt'        => esc_html__('Excerpt', 'escoot'),
                        'rating'         => esc_html__('Rating', 'escoot'),
                        'button_element' => esc_html__('Button Element', 'escoot')
                    ),
                    'disabled'     => array (
						'price'          => esc_html__('Price', 'escoot'),
                        'countdown'      => esc_html__('Count Down', 'escoot'),
                        'separator'      => esc_html__('Separator', 'escoot'),
                        'element_group'  => esc_html__('Element Group', 'escoot'),
                        'swatches'       => esc_html__('Swatches', 'escoot'),
                        'category'       => esc_html__('Category', 'escoot')
                    )
                );
                $type_options['product-content-alignment']        	  = 'center';
                $type_options['product-content-iconsgroup-style'] 	  = 'product-content-iconsgroup-style-simple';
                $type_options['product-content-buttonelement-button'] = 'cart-with-quantity';
                $type_options['product-content-buttonelement-style']  = 'product-content-buttonelement-style-skinbgfill-rounded';                

                return $type_options;
            }

        /*
        Frontend Render
        */
            function render_frontend() {

                $non_archive_listing = wc_get_loop_prop('non_archive_listing');

                if( $non_archive_listing ) {

                    /* Types CSS */
                        add_filter( 'escoot_woo_non_archive_css', array( $this, 'woo_listings_css_load'), 10, 1 );

                } else {

                    /* Types CSS */
                        add_filter( 'escoot_woo_archive_css', array( $this, 'woo_listings_css_load'), 10, 1 );

                }

            }

        /*
        Types CSS
        */
            function woo_listings_css_load( $css ) {

                $css .= $this->load_type_css();
                $css .= $this->load_type_skin_css();

                return $css;

            }

            // Type Main CSS
            function load_type_css() {

                $css = '';

                $css_file_path = $this->module_dir_path() . 'assets/css/'.$this->type_slug.'.css';

                if( file_exists ( $css_file_path ) ) {

                    ob_start();
                    include( $css_file_path );
                    $css .= "\n\n".ob_get_clean();

                }

                return $css;

            }

            // Type Skin CSS
            function load_type_skin_css() {

                $css = '';
                return $css;

            }

        /*
        For Non Archive Listing
        */
            function for_non_archive_listing() {

                /* Load Other Modules */

                    $sub_modules = array (
                        'includes' => 'listings/includes/index'
                    );

                    if( is_array( $sub_modules ) && !empty( $sub_modules ) ) {
                        foreach( $sub_modules as $sub_module ) {

                            if( $file_content = escoot_woo_locate_file( $sub_module ) ) {
                                include_once $file_content;
                            }

                        }
                    }


                /* Assets Load */

                    // CSS

                        wp_register_style( 'escoot-woo-non-archive', '', array (), ESCOOT_THEME_VERSION, 'all' );
                        wp_enqueue_style( 'escoot-woo-non-archive' );

                        $css = '';

                        // Load common styles
                        if( !is_shop() && !is_product_category() && !is_product_tag() && !is_product() && !is_cart() && !is_checkout() ) {
                            $css_file_path = ESCOOT_MODULE_DIR . '/woocommerce/assets/css/common.css';

                            if( file_exists ( $css_file_path ) ) {

                                ob_start();
                                include( $css_file_path );
                                $css .= "\n\n".ob_get_clean();

                            }

 							$css_file_path = ESCOOT_MODULE_DIR . '/woocommerce/single/assets/css/common.css';

                            if( file_exists ( $css_file_path ) ) {

                                ob_start();
                                include( $css_file_path );
                                $css .= "\n\n".ob_get_clean();

                            }
                        }

                        $css = apply_filters( 'escoot_woo_non_archive_css', $css );

                        if( !empty($css) ) {
                            wp_add_inline_style( 'escoot-woo-non-archive', $css );
                        }

                    // JS

                        wp_register_script( 'escoot-woo-non-archive', '', array ('jquery'), false, true );
                        wp_enqueue_script( 'escoot-woo-non-archive' );

                        $js = '';

                        // Load common js
                        if( !is_shop() && !is_product_category() && !is_product_tag() && !is_product() && !is_cart() && !is_checkout() ) {
                            $js_file_path = ESCOOT_MODULE_DIR . '/woocommerce/assets/js/common.js';

                            if( file_exists ( $js_file_path ) ) {

                                ob_start();
                                include( $js_file_path );
                                $js .= "\n\n".ob_get_clean();

                            }
                        }

                        $js = apply_filters( 'escoot_woo_non_archive_js', $js );

                        if( !empty($js) ) {
                            wp_add_inline_script( 'escoot-woo-non-archive', $js );
                        }

            }

    }

}

if( !function_exists('dt_woo_listing_type_default') ) {
	function dt_woo_listing_type_default() {
		return Dt_Woo_Listing_Type_Default::instance();
	}
}

dt_woo_listing_type_default();