<?php
use DTElementor\Widgets\DTElementorWidgetBase;
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Utils;

class Elementor_Blog_Posts extends DTElementorWidgetBase {

    public function get_name() {
        return 'dt-blog-posts';
    }

    public function get_title() {
        return esc_html__('Blog Posts', 'designthemes-theme');
    }

    public function get_icon() {
		return 'fa fa-thumb-tack';
	}

	public function get_style_depends() {
		return array( 'swiper', 'dt-blogcarousel' );
	}

	public function get_script_depends() {
		return array( 'jquery-swiper', 'dt-blogcarousel' );
	}

    protected function register_controls() {

        $this->start_controls_section( 'dt_section_general', array(
            'label' => esc_html__( 'General', 'designthemes-theme'),  
        ) );

            $this->add_control( 'query_posts_by', array(
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__('Query posts by', 'designthemes-theme'),
                'default' => 'category',
                'options' => array(
                    'category'  => esc_html__('From Category (for Posts only)', 'designthemes-theme'),
                    'ids'       => esc_html__('By Specific IDs', 'designthemes-theme'),
                )
            ) );

            $this->add_control( '_post_categories', array(
                'label'       => esc_html__( 'Categories', 'designthemes-theme' ),
                'type'        => Controls_Manager::SELECT2,
                'label_block' => true,
                'multiple'    => true,
                'options'     => $this->dt_post_categories(),
                'condition' => array( 'query_posts_by' => 'category' )
            ) );

            $this->add_control( '_post_ids', array(
                'label'       => esc_html__( 'Select Specific Posts', 'designthemes-theme' ),
                'type'        => Controls_Manager::SELECT2,
                'label_block' => true,
                'multiple'    => true,
                'options'     => $this->dt_post_ids(),
                'condition' => array( 'query_posts_by' => 'ids' )
            ) );

            $this->add_control( 'count', array(
                'type'        => Controls_Manager::NUMBER,
                'label'       => esc_html__('Post Counts', 'designthemes-theme'),
                'default'     => '5',
                'placeholder' => esc_html__( 'Enter post count', 'designthemes-theme' ),
            ) );

            $this->add_control( 'blog_post_layout', array(
                'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__('Post Layout', 'designthemes-theme'),
                'default' => 'entry-grid',
                'options' => array(
                    'entry-grid'  => esc_html__('Grid', 'designthemes-theme'),
                    'entry-list'  => esc_html__('List', 'designthemes-theme'),
                    'entry-cover' => esc_html__('Cover', 'designthemes-theme'),
                )
            ) );

            $this->add_control( 'blog_post_grid_list_style', array(
                'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__('Post Style', 'designthemes-theme'),
                'default' => 'dt-sc-boxed',
                'options' => array(
                    'dt-sc-boxed'           => esc_html__('Boxed', 'designthemes-theme'),
                    'dt-sc-simple'          => esc_html__('Simple', 'designthemes-theme'),
                    'dt-sc-overlap'         => esc_html__('Overlap', 'designthemes-theme'),
                    'dt-sc-content-overlay' => esc_html__('Content Overlay', 'designthemes-theme'),
                    'dt-sc-simple-withbg'   => esc_html__('Simple with Background', 'designthemes-theme'),
                    'dt-sc-overlay'         => esc_html__('Overlay', 'designthemes-theme'),
                    'dt-sc-overlay-ii'      => esc_html__('Overlay II', 'designthemes-theme'),
                    'dt-sc-overlay-iii'     => esc_html__('Overlay III', 'designthemes-theme'),
                    'dt-sc-alternate'       => esc_html__('Alternate', 'designthemes-theme'),
                    'dt-sc-minimal'         => esc_html__('Minimal', 'designthemes-theme'),
                    'dt-sc-modern'          => esc_html__('Modern', 'designthemes-theme'),
                    'dt-sc-classic'         => esc_html__('Classic', 'designthemes-theme'),
                    'dt-sc-classic-ii'      => esc_html__('Classic II', 'designthemes-theme'),
                    'dt-sc-classic-overlay' => esc_html__('Classic Overlay', 'designthemes-theme'),
                    'dt-sc-grungy-boxed'    => esc_html__('Grungy Boxed', 'designthemes-theme'),
                    'dt-sc-title-overlap'   => esc_html__('Title Overlap', 'designthemes-theme'),
                ),
                'condition' => array( 'blog_post_layout' => array( 'entry-grid', 'entry-list' ) )
            ) );

            $this->add_control( 'blog_post_cover_style', array(
                'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__('Post Style', 'designthemes-theme'),
                'default' => 'dt-sc-boxed',
                'options' => array(
                    'dt-sc-boxed'           => esc_html__('Boxed', 'designthemes-theme'),
                    'dt-sc-canvas'          => esc_html__('Canvas', 'designthemes-theme'),
                    'dt-sc-content-overlay' => esc_html__('Content Overlay', 'designthemes-theme'),
                    'dt-sc-overlay'         => esc_html__('Overlay', 'designthemes-theme'),
                    'dt-sc-overlay-ii'      => esc_html__('Overlay II', 'designthemes-theme'),
                    'dt-sc-overlay-iii'     => esc_html__('Overlay III', 'designthemes-theme'),
                    'dt-sc-trendy'          => esc_html__('Trendy', 'designthemes-theme'),
                    'dt-sc-mobilephone'     => esc_html__('Mobile Phone', 'designthemes-theme'),
                ),
                'condition' => array( 'blog_post_layout' => 'entry-cover' )
            ) );

            $this->add_control( 'blog_post_columns', array(
                'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__('Columns', 'designthemes-theme'),
                'default' => 'one-third-column',
                'options' => array(
                    'one-column'        => esc_html__('I Column', 'designthemes-theme'),
                    'one-half-column'   => esc_html__('II Columns', 'designthemes-theme'),
                    'one-third-column'  => esc_html__('III Columns', 'designthemes-theme'),
                    'one-fourth-column' => esc_html__('IV Columns', 'designthemes-theme'),
                ),
                'condition' => array( 'blog_post_layout' => array( 'entry-grid', 'entry-cover' ) )
            ) );

            $this->add_control( 'blog_list_thumb', array(
                'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__('List Type', 'designthemes-theme'),
                'default' => 'entry-left-thumb',
                'options' => array(
                    'entry-left-thumb'  => esc_html__('Left Thumb', 'designthemes-theme'),
                    'entry-right-thumb' => esc_html__('Right Thumb', 'designthemes-theme'),
                ),
                'condition' => array( 'blog_post_layout' => 'entry-list' )
            ) );

            $this->add_control( 'blog_alignment', array(
                'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__('Elements Alignment', 'designthemes-theme'),
                'default' => 'alignnone',
                'options' => array(
                    'alignnone'   => esc_html__('None', 'designthemes-theme'),
                    'alignleft'   => esc_html__('Align Left', 'designthemes-theme'),
                    'aligncenter' => esc_html__('Align Center', 'designthemes-theme'),
                    'alignright'  => esc_html__('Align Right', 'designthemes-theme'),
                ),
                'condition' => array( 'blog_post_layout' => array( 'entry-grid', 'entry-cover' ) )
            ) );
        
            $this->add_control( 'enable_equal_height', array(
                'type'         => Controls_Manager::SWITCHER,
                'label'        => esc_html__('Enable Equal Height?', 'designthemes-theme'),
                'label_on'     => esc_html__( 'Yes', 'designthemes-theme' ),
                'label_off'    => esc_html__( 'No', 'designthemes-theme' ),
                'return_value' => 'yes',
                'default'      => '',
                'condition'    => array( 'blog_post_layout' => array( 'entry-grid', 'entry-cover' ) )
            ) );

            $this->add_control( 'enable_no_space', array(
                'type'         => Controls_Manager::SWITCHER,
                'label'        => esc_html__('Enable No Space?', 'designthemes-theme'),
                'label_on'     => esc_html__( 'Yes', 'designthemes-theme' ),
                'label_off'    => esc_html__( 'No', 'designthemes-theme' ),
                'return_value' => 'yes',
                'default'      => '',
                'condition'    => array( 'blog_post_layout' => array( 'entry-grid', 'entry-cover' ) )
            ) );

            $this->add_control( 'enable_gallery_slider', array(
                'type'         => Controls_Manager::SWITCHER,
                'label'        => esc_html__('Display Gallery Slider?', 'designthemes-theme'),
                'label_on'     => esc_html__( 'Yes', 'designthemes-theme' ),
                'label_off'    => esc_html__( 'No', 'designthemes-theme' ),
                'return_value' => 'yes',
                'default'      => '',
                'condition'    => array( 'blog_post_layout' => array( 'entry-grid', 'entry-list' ) ),
            ) );

            $content = new Repeater();
            $content->add_control( 'element_value', array(
                'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__('Element', 'designthemes-theme'),
                'default' => 'feature_image',
                'options' => array(
                    'feature_image' => esc_html__('Feature Image', 'designthemes-theme'),
                    'title'         => esc_html__('Title', 'designthemes-theme'),
                    'content'       => esc_html__('Content', 'designthemes-theme'),
                    'read_more'     => esc_html__('Read More', 'designthemes-theme'),
                    'meta_group'    => esc_html__('Meta Group', 'designthemes-theme'),
                    'author'        => esc_html__('Author', 'designthemes-theme'),
                    'date'          => esc_html__('Date', 'designthemes-theme'),
                    'comment'       => esc_html__('Comments', 'designthemes-theme'),
                    'category'      => esc_html__('Categories', 'designthemes-theme'),
                    'tag'           => esc_html__('Tags', 'designthemes-theme'),
                    'social'        => esc_html__('Social Share', 'designthemes-theme'),
                    'likes_views'   => esc_html__('Likes & Views', 'designthemes-theme'),
                ),
            ) );

            $this->add_control( 'blog_elements_position', array(
                'type'        => Controls_Manager::REPEATER,
                'label'       => esc_html__('Elements & Positioning', 'designthemes-theme'),
                'fields'      => array_values( $content->get_controls() ),
                'default'     => array(
                    array( 'element_value' => 'title' ),
                ),
                'title_field' => '{{{ element_value.replace( \'_\', \' \' ).replace( /\b\w/g, function( letter ){ return letter.toUpperCase() } ) }}}'
            ) );

            $content = new Repeater();
            $content->add_control( 'element_value', array(
                'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__('Element', 'designthemes-theme'),
                'default' => 'author',
                'options' => array(
                    'author'       => esc_html__('Author', 'designthemes-theme'),
                    'date'         => esc_html__('Date', 'designthemes-theme'),
                    'comment'      => esc_html__('Comments', 'designthemes-theme'),
                    'category'     => esc_html__('Categories', 'designthemes-theme'),
                    'tag'          => esc_html__('Tags', 'designthemes-theme'),
                    'social'       => esc_html__('Social Share', 'designthemes-theme'),
                    'likes_views'  => esc_html__('Likes & Views', 'designthemes-theme'),
                ),
            ) );

            $this->add_control( 'blog_meta_position', array(
                'type'        => Controls_Manager::REPEATER,
                'label'       => esc_html__('Meta Group Positioning', 'designthemes-theme'),
                'fields'      => array_values( $content->get_controls() ),
                'default'     => array(
                    array( 'element_value' => 'author' ),
                ),
                'title_field' => '{{{ element_value.replace( \'_\', \' \' ).replace( /\b\w/g, function( letter ){ return letter.toUpperCase() } ) }}}'
            ) );

            $this->add_control( 'enable_post_format', array(
                'type'         => Controls_Manager::SWITCHER,
                'label'        => esc_html__('Enable Post Format?', 'designthemes-theme'),
                'label_on'     => esc_html__( 'Yes', 'designthemes-theme' ),
                'label_off'    => esc_html__( 'No', 'designthemes-theme' ),
                'return_value' => 'yes',
                'default'      => '',
            ) );
        
            $this->add_control( 'enable_video_audio', array(
                'type'         => Controls_Manager::SWITCHER,
                'label'        => esc_html__('Display Video & Audio for Posts?', 'designthemes-theme'),
                'label_on'     => esc_html__( 'Yes', 'designthemes-theme' ),
                'label_off'    => esc_html__( 'No', 'designthemes-theme' ),
                'return_value' => 'yes',
                'default'      => '',
                'condition'    => array( 'blog_post_layout' => array( 'entry-grid', 'entry-list' ) ),
                'description'  => esc_html__( 'YES! to display video & audio, instead of feature image for posts', 'designthemes-theme' ),
            ) );

            $this->add_control( 'enable_excerpt_text', array(
                'type'         => Controls_Manager::SWITCHER,
                'label'        => esc_html__('Enable Excerpt Text?', 'designthemes-theme'),
                'label_on'     => esc_html__( 'Yes', 'designthemes-theme' ),
                'label_off'    => esc_html__( 'No', 'designthemes-theme' ),
                'return_value' => 'yes',
                'default'      => '',
            ) );

            $this->add_control( 'blog_excerpt_length', array(
                'type'      => Controls_Manager::NUMBER,
                'label'     => esc_html__('Excerpt Length', 'designthemes-theme'),
                'default'   => '25',
                'condition' => array( 'enable_excerpt_text' => 'yes' )
            ) );

            $this->add_control( 'blog_readmore_text', array(
                'type'        => Controls_Manager::TEXT,
                'label'       => esc_html__('Read More Text', 'designthemes-theme'),
                'default'     => esc_html__('Read More', 'designthemes-theme'),
            ) );

            $this->add_control( 'blog_image_hover_style', array(
                'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__('Image Hover Style', 'designthemes-theme'),
                'default' => 'dt-sc-default',
                'options' => array(
                    'dt-sc-default'     => esc_html__('Default', 'designthemes-theme'),
                    'dt-sc-blur'        => esc_html__('Blur', 'designthemes-theme'),
                    'dt-sc-bw'          => esc_html__('Black and White', 'designthemes-theme'),
                    'dt-sc-brightness'  => esc_html__('Brightness', 'designthemes-theme'),
                    'dt-sc-fadeinleft'  => esc_html__('Fade InLeft', 'designthemes-theme'),
                    'dt-sc-fadeinright' => esc_html__('Fade InRight', 'designthemes-theme'),
                    'dt-sc-hue-rotate'  => esc_html__('Hue-Rotate', 'designthemes-theme'),
                    'dt-sc-invert'      => esc_html__('Invert', 'designthemes-theme'),
                    'dt-sc-opacity'     => esc_html__('Opacity', 'designthemes-theme'),
                    'dt-sc-rotate'      => esc_html__('Rotate', 'designthemes-theme'),
                    'dt-sc-rotate-alt'  => esc_html__('Rotate Alt', 'designthemes-theme'),
                    'dt-sc-scalein'     => esc_html__('Scale In', 'designthemes-theme'),
                    'dt-sc-scaleout'    => esc_html__('Scale Out', 'designthemes-theme'),
                    'dt-sc-sepia'       => esc_html__('Sepia', 'designthemes-theme'),
                    'dt-sc-tint'        => esc_html__('Tint', 'designthemes-theme'),
                ),
                'description' => esc_html__('Note: Fade, Rotate & Scale Styles will not work for Gallery Sliders.', 'designthemes-theme'),
            ) );

            $this->add_control( 'blog_image_overlay_style', array(
                'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__('Image Overlay Style', 'designthemes-theme'),
                'default' => 'dt-sc-default',
                'options' => array(
                    'dt-sc-default'         => esc_html__('None', 'designthemes-theme'),
                    'dt-sc-fixed'           => esc_html__('Fixed', 'designthemes-theme'),
                    'dt-sc-tb'              => esc_html__('Top to Bottom', 'designthemes-theme'),
                    'dt-sc-bt'              => esc_html__('Bottom to Top', 'designthemes-theme'),
                    'dt-sc-rl'              => esc_html__('Right to Left', 'designthemes-theme'),
                    'dt-sc-lr'              => esc_html__('Left to Right', 'designthemes-theme'),
                    'dt-sc-middle'          => esc_html__('Middle', 'designthemes-theme'),
                    'dt-sc-middle-radial'   => esc_html__('Middle Radial', 'designthemes-theme'),
                    'dt-sc-tb-gradient'     => esc_html__('Gradient - Top to Bottom', 'designthemes-theme'),
                    'dt-sc-bt-gradient'     => esc_html__('Gradient - Bottom to Top', 'designthemes-theme'),
                    'dt-sc-rl-gradient'     => esc_html__('Gradient - Right to Left', 'designthemes-theme'),
                    'dt-sc-lr-gradient'     => esc_html__('Gradient - Left to Right', 'designthemes-theme'),
                    'dt-sc-radial-gradient' => esc_html__('Gradient - Radial', 'designthemes-theme'),
                    'dt-sc-flash'           => esc_html__('Flash', 'designthemes-theme'),
                    'dt-sc-circle'          => esc_html__('Circle', 'designthemes-theme'),
                    'dt-sc-hm-elastic'      => esc_html__('Horizontal Elastic', 'designthemes-theme'),
                    'dt-sc-vm-elastic'      => esc_html__('Vertical Elastic', 'designthemes-theme'),
                ),
                'condition' => array( 'blog_post_layout' => array( 'entry-grid', 'entry-list' ) )
            ) );

            $this->add_control( 'blog_pagination', array(
                'type'    => Controls_Manager::SELECT,
				'label'   => esc_html__('Pagination Style', 'designthemes-theme'),
                'default' => 'older_newer',
                'options' => array(
                    ''                => esc_html__('None', 'designthemes-theme'),
                    'older_newer'     => esc_html__('Older & Newer', 'designthemes-theme'),
                    'numbered'        => esc_html__('Numbered', 'designthemes-theme'),
                    'load_more'       => esc_html__('Load More', 'designthemes-theme'),
                    'infinite_scroll' => esc_html__('Infinite Scroll', 'designthemes-theme'),
                    'carousel'        => esc_html__('Carousel', 'designthemes-theme'),
                ),
            ) );

            $this->add_control( 'el_class', array(
                'type'        => Controls_Manager::TEXT,
                'label'       => esc_html__('Extra class name', 'designthemes-theme'),
                'description' => esc_html__('Style particular element differently - add a class name and refer to it in custom CSS', 'designthemes-theme')
            ) );

        $this->end_controls_section();

		$this->start_controls_section( 'blog_carousel_section', array(
			'label'     => esc_html__( 'Carousel Settings', 'designthemes-theme' ),
			'condition' => array( 'blog_pagination' => 'carousel' ),
		) );
			$this->add_control( 'carousel_effect', array(
				'label'       => esc_html__( 'Effect', 'designthemes-theme' ),
				'type'        => Controls_Manager::SELECT,
				'description' => esc_html__( 'Choose effect for your carousel. Slides Per View has to be 1 for Fade effect.', 'designthemes-theme' ),
				'default'     => '',
				'options'     => array(
					''     => esc_html__( 'Default', 'designthemes-theme' ),
					'fade' => esc_html__( 'Fade', 'designthemes-theme' ),
	            ),
	        ) );

			$this->add_control( 'carousel_slidesperview', array(
				'label'       => esc_html__( 'Slides Per View', 'designthemes-theme' ),
				'type'        => Controls_Manager::SELECT,
				'description' => esc_html__( 'Number slides of to show in view port.', 'designthemes-theme' ),
				'options'     => array( 1 => 1, 2 => 2, 3 => 3, 4 => 4 ),
				'default'     => 2,
	        ) );

			$this->add_control( 'carousel_loopmode', array(
				'label'        => esc_html__( 'Enable Loop Mode', 'designthemes-theme' ),
				'type'         => Controls_Manager::SWITCHER,
				'description'  => esc_html__('If you wish, you can enable continuous loop mode for your carousel.', 'designthemes-theme'),
				'label_on'     => esc_html__( 'yes', 'designthemes-theme' ),
				'label_off'    => esc_html__( 'no', 'designthemes-theme' ),
				'default'      => '',
				'return_value' => 'true',
			) );

			$this->add_control( 'carousel_mousewheelcontrol', array(
				'label'        => esc_html__( 'Enable Mousewheel Control', 'designthemes-theme' ),
				'type'         => Controls_Manager::SWITCHER,
				'description'  => esc_html__('If you wish, you can enable mouse wheel control for your carousel.', 'designthemes-theme'),
				'label_on'     => esc_html__( 'yes', 'designthemes-theme' ),
				'label_off'    => esc_html__( 'no', 'designthemes-theme' ),
				'default'      => '',
				'return_value' => 'true',
			) );

			$this->add_control( 'carousel_bulletpagination', array(
				'label'        => esc_html__( 'Enable Bullet Pagination', 'designthemes-theme' ),
				'type'         => Controls_Manager::SWITCHER,
				'description'  => esc_html__('To enable bullet pagination.', 'designthemes-theme'),
				'label_on'     => esc_html__( 'yes', 'designthemes-theme' ),
				'label_off'    => esc_html__( 'no', 'designthemes-theme' ),
				'default'      => '',
				'return_value' => 'true',
			) );

			$this->add_control( 'carousel_arrowpagination', array(
				'label'        => esc_html__( 'Enable Arrow Pagination', 'designthemes-theme' ),
				'type'         => Controls_Manager::SWITCHER,
				'description'  => esc_html__('To enable arrow pagination.', 'designthemes-theme'),
				'label_on'     => esc_html__( 'yes', 'designthemes-theme' ),
				'label_off'    => esc_html__( 'no', 'designthemes-theme' ),
				'default'      => '',
				'return_value' => 'true',
			) );

			$this->add_control( 'carousel_arrowpagination_type', array(
				'label'       => esc_html__( 'Arrow Type', 'designthemes-theme' ),
				'type'        => Controls_Manager::SELECT,
				'description' => esc_html__( 'Choose arrow pagination type for your carousel.', 'designthemes-theme' ),
				'options'     => array( 
					''      => esc_html__('Default', 'designthemes-theme'), 
					'type2' => esc_html__('Type 2', 'designthemes-theme'), 
				),
				'condition'   => array( 'carousel_arrowpagination' => 'true' ),				
				'default'     => '',
	        ) );

			$this->add_control( 'carousel_scrollbar', array(
				'label'        => esc_html__( 'Enable Scrollbar', 'designthemes-theme' ),
				'type'         => Controls_Manager::SWITCHER,
				'description'  => esc_html__('To enable scrollbar for your carousel.', 'designthemes-theme'),
				'label_on'     => esc_html__( 'yes', 'designthemes-theme' ),
				'label_off'    => esc_html__( 'no', 'designthemes-theme' ),
				'default'      => '',
				'return_value' => 'true',
			) );

		$this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        extract($settings);

		$out = '';

		$media_carousel_attributes_string = $container_class = $wrapper_class = $item_class = '';

		if( $blog_pagination == 'carousel' ) {

			$media_carousel_attributes = array ();

			array_push( $media_carousel_attributes, 'data-carouseleffect="'.$settings['carousel_effect'].'"' );
			array_push( $media_carousel_attributes, 'data-carouselslidesperview="'.$settings['carousel_slidesperview'].'"' );
			array_push( $media_carousel_attributes, 'data-carouselloopmode="'.$settings['carousel_loopmode'].'"' );
			array_push( $media_carousel_attributes, 'data-carouselmousewheelcontrol="'.$settings['carousel_mousewheelcontrol'].'"' );
			array_push( $media_carousel_attributes, 'data-carouselbulletpagination="'.$settings['carousel_bulletpagination'].'"' );
			array_push( $media_carousel_attributes, 'data-carouselarrowpagination="'.$settings['carousel_arrowpagination'].'"' );
			array_push( $media_carousel_attributes, 'data-carouselscrollbar="'.$settings['carousel_scrollbar'].'"' );

			if( !empty( $media_carousel_attributes ) ) {
				$media_carousel_attributes_string = implode(' ', $media_carousel_attributes);
			}

			$container_class = 'swiper-container';
			$wrapper_class = 'swiper-wrapper';
			$item_class = 'swiper-slide';

			$out .= '<div class="dt-sc-post-list-carousel-container">';
		}

		$out .= '<div class="dt-sc-posts-list-wrapper '.$container_class.' '.$el_class.'" '.$media_carousel_attributes_string.'>';

		if ( get_query_var('paged') ) {
			$paged = get_query_var('paged');
		} elseif ( get_query_var('page') ) { 
			$paged = get_query_var('page');
		} else {
			$paged = 1;
		}

		$args = array( 'paged' => $paged, 'posts_per_page' => $count, 'orderby' => 'date', 'ignore_sticky_posts' => true, 'post_status' => 'publish' );
		$warning = esc_html__('No Posts Found','designthemes-theme');

		if( !empty( $_post_categories ) && $query_posts_by == 'category' ) {
            $_post_categories = implode( ',', $_post_categories );
			$args = array( 'paged' => $paged, 'posts_per_page' => $count, 'orderby' => 'date', 'cat' => $_post_categories, 'ignore_sticky_posts' => true, 'post_status' => 'publish' );
			$warning = esc_html__('No Posts Found in Category ','designthemes-theme').$_post_categories;
		} elseif( $query_posts_by == 'ids' && !empty( $_post_ids ) ) {
            $args = array( 'paged' => $paged, 'posts_per_page' => $count, 'orderby' => 'date', 'post__in' => $_post_ids, 'ignore_sticky_posts' => true, 'post_status' => 'publish' );
            $warning = esc_html__('No Posts Found in Criteria ','designthemes-theme').$_post_categories;
        }

		if( !empty( $_post_not_in ) ) {
			$args['post__not_in'] = array( $_post_not_in );
            $settings['blog_excerpt_length'] = 25;
		}

		$rposts = new WP_Query( $args );
		if ( $rposts->have_posts() ) :

           	do_action( 'call_blog_elementor_sc_filters', $settings );

            $holder_class  = escoot_get_archive_post_holder_class();
            $combine_class = escoot_get_archive_post_combine_class();

            $post_style    = escoot_get_archive_post_style();
            $template_args['Post_Style'] = $post_style;
            $template_args = array_merge( $template_args, escoot_archive_blog_post_params() );
            $template_args = apply_filters( 'escoot_blog_archive_order_params', $template_args );

            $out .= "<div class='tpl-blog-holder ".$holder_class."'>";
            $out .= "<div class='grid-sizer ".$combine_class."'></div>";

                while( $rposts->have_posts() ) :
                    $rposts->the_post();
                    $post_ID = get_the_ID();

                    $out .= '<div class="'.esc_attr($combine_class).'">';
                        $out .= '<!-- #post-'. $post_ID .' -->';
                        $out .= '<article id="post-'.$post_ID.'" class="' . implode( ' ', get_post_class( '', $post_ID ) ) . '">';

                            $template_args['ID'] = $post_ID;
                            $out .= escoot_get_template_part( 'blog', 'templates/'.$post_style.'/post', '', $template_args );
                        $out .= '</article><!-- #post-'. $post_ID .' -->';
                    $out .= '</div>';
                endwhile;

			wp_reset_postdata($rposts);

            $out .= '</div>';

			if( $blog_pagination == 'numbered' ):

				$out .= '<div class="pagination blog-pagination">'.escoot_pagination($rposts).'</div>';

			elseif( $blog_pagination == 'older_newer' ):

				$out .= '<div class="pagination blog-pagination"><div class="newer-posts">'.get_previous_posts_link( '<i class="fa fa-angle-left"></i>'.esc_html__(' Newer Posts', 'designthemes-theme') ).'</div>';
				$out .= '<div class="older-posts">'.get_next_posts_link( esc_html__('Older Posts ', 'designthemes-theme').'<i class="fa fa-angle-right"></i>', $rposts->max_num_pages ).'</div></div>';

			elseif( $blog_pagination == 'load_more' ):

				//$pos = $count % $columns;
				//$pos += 1;
                $pos = 1;
                $_post_categories = !empty( $_post_categories ) ? $_post_categories : '';

				$out .= "<div class='pagination blog-pagination'><a class='loadmore-elementor-btn more-items' data-count='".$count."' data-cats='".$_post_categories."' data-maxpage='".esc_attr($rposts->max_num_pages)."' data-pos='".esc_attr($pos)."' data-eheight='".esc_attr($enable_equal_height)."' data-style='".esc_attr($post_style)."' data-layout='".esc_attr($blog_post_layout)."' data-column='".esc_attr($blog_post_columns)."' data-listtype='".esc_attr($blog_list_thumb)."' data-hover='".esc_attr($blog_image_hover_style)."' data-overlay='".esc_attr($blog_image_overlay_style)."' data-align='".esc_attr($blog_alignment)."' href='javascript:void(0);' data-meta='' data-blogpostloadmore-nonce='".wp_create_nonce('blogpostloadmore_nonce')."' data-settings='".http_build_query($settings)."'>".esc_html__('Load More', 'designthemes-theme')."</a></div>";

			elseif( $blog_pagination == 'infinite_scroll' ):

				//$pos = $count % $columns;
				//$pos += 1;
                $pos = 1;
                $_post_categories = !empty( $_post_categories ) ? $_post_categories : '';

                $out .= "<div class='pagination blog-pagination'><div class='infinite-elementor-btn more-items' data-count='".$count."' data-cats='".$_post_categories."' data-maxpage='".esc_attr($rposts->max_num_pages)."' data-pos='".esc_attr($pos)."' data-eheight='".esc_attr($enable_equal_height)."' data-style='".esc_attr($post_style)."' data-layout='".esc_attr($blog_post_layout)."' data-column='".esc_attr($blog_post_columns)."' data-listtype='".esc_attr($blog_list_thumb)."' data-hover='".esc_attr($blog_image_hover_style)."' data-overlay='".esc_attr($blog_image_overlay_style)."' data-align='".esc_attr($blog_alignment)."' data-meta='' data-blogpostloadmore-nonce='".wp_create_nonce('blogpostloadmore_nonce')."' data-settings='".http_build_query($settings)."'></div></div>";

			elseif( $blog_pagination == 'carousel' ):

				$out .= '<div class="dt-sc-products-pagination-holder">';

					if( $settings['carousel_bulletpagination'] == 'true' ) {
						$out .= '<div class="dt-sc-products-bullet-pagination"></div>';	
					}

					if( $settings['carousel_scrollbar'] == 'true' ) {
						$out .= '<div class="dt-sc-products-scrollbar"></div>';	
					}											

					if( $settings['carousel_arrowpagination'] == 'true' ) {
						$out .= '<div class="dt-sc-products-arrow-pagination '.$settings['carousel_arrowpagination_type'].'">';
							$out .= '<a href="#" class="dt-sc-products-arrow-prev">'.esc_html__('Prev', 'designthemes-theme').'</a>';
							$out .= '<a href="#" class="dt-sc-products-arrow-next">'.esc_html__('Next', 'designthemes-theme').'</a>';
						$out .= '</div>';
					}

				$out .= '</div>';

			endif;

		else:
			$out .= "<div class='dt-sc-warning-box'>{$warning}</div>";
		endif;

		$out .= '</div>';

		if( $blog_pagination == 'carousel' ) {
			$out .= '</div>';
		}

        echo $out;
    }

    protected function _content_template() {
    }
}